<template>
  <ProTabs
    v-model="queryState.flexTaskReleaseStatus"
    name="home-tab"
    :showPaneContent="false"
    class="home-tabs"
    isTransparent
    title-gutter="12"
    title-scroll
  >
    <ProTabPane
      :title="`${
        FlexTaskReleaseStatusEnumText[FlexTaskReleaseStatusEnum.Releasing]
      }(${releaseing})`"
      :pane-key="FlexTaskReleaseStatusEnum.Releasing"
    ></ProTabPane>
    <ProTabPane
      :title="`${FlexTaskReleaseStatusEnumText[FlexTaskReleaseStatusEnum.Stoping]}(${stoping})`"
      :pane-key="FlexTaskReleaseStatusEnum.Stoping"
    ></ProTabPane>
  </ProTabs>
  <InfiniteLoading
    scrollViewClassName="common-infinite-scroll-list home-list"
    v-bind="infiniteLoadingProps"
    :key="queryState.flexTaskReleaseStatus"
  >
    <template #renderItem="{ item }">
      <JobApplicationCard
        :taskName="item.taskName"
        :startDate="item.startDate"
        :endDate="item.endDate"
        :creationTime="item.creationTime"
        :address="item.address"
        :fee="item.fee"
        :applyWorkerCount="item.applyWorkerCount"
        :unit="SalaryTimeTypeEnumUnit[item.feeType]"
        :releaseStatus="item.releaseStatus"
        @edit="goEdit(item)"
        @copy="goEdit(item, true)"
        @detail="goDetail(item)"
        @publish="handleChangeStatus(item, FlexTaskReleaseStatusEnum.Releasing)"
        @stop="handleChangeStatus(item, FlexTaskReleaseStatusEnum.Stoping)"
        @delete="handleDelete(item)"
      >
      </JobApplicationCard>
    </template>
  </InfiniteLoading>
</template>

<script setup lang="ts">
import { JobApplicationCard, ProTabs, ProTabPane } from '@12333/components';
import { RouterPath } from '@/constants';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import {
  FlexTaskReleaseStatusEnum,
  FlexTaskReleaseStatusEnumText,
  SalaryTimeTypeEnumUnit,
} from '@/constants/task';
import * as flexWorkerServices from '@12333/services/api/FlexWorker';
import Taro from '@tarojs/taro';
import { Message } from '@12333/utils';

defineOptions({
  name: 'InnerPage',
});

const queryState = reactive({
  flexTaskReleaseStatus: FlexTaskReleaseStatusEnum.Releasing,
});

const { infiniteLoadingProps, invalidateQueries } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.GetFlexTaskListByStatusInput = {
      releaseStatus: queryState.flexTaskReleaseStatus,
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [{ property: 'creationTime', order: OrderInputType.Desc }],
      },
    };

    return flexWorkerServices.getFlexTaskList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['flexWorkerServices/getFlexTaskList', queryState],
  }
);

const releaseing = computed(() => {
  return infiniteLoadingProps.value?.listData?.pages?.[0]?.objectData?.releaseing ?? 0;
});
const stoping = computed(() => {
  return infiniteLoadingProps.value?.listData?.pages?.[0]?.objectData?.stoping ?? 0;
});

async function handleChangeStatus(
  item: API.GetFlexTaskListOutput,
  releaseStatus: FlexTaskReleaseStatusEnum
) {
  try {
    let params: API.UpdateTaskReleaseStatusInput = {
      taskId: item.taskId,
      releaseStatus: releaseStatus,
    };
    let res = await flexWorkerServices.updateFlexTaskReleaseStatus(params);
    if (res) {
      Message.success('操作成功');
      invalidateQueries();
    }
  } catch (error) {}
}

async function handleDelete(item: API.GetFlexTaskListOutput) {
  try {
    await Message.confirm({
      message: '确定要删除吗？',
    });
    let params: API.APIdeleteFlexTaskParams = {
      id: item.taskId,
    };
    let res = await flexWorkerServices.deleteFlexTask(params);
    if (res) {
      Message.success('删除成功');
      invalidateQueries();
    }
  } catch (error) {}
}

function goEdit(item: API.GetFlexTaskListOutput, isCopy = false) {
  Taro.navigateTo({
    url: `${RouterPath.publishTask}?taskId=${item.taskId}&isCopy=${isCopy}`,
  });
}
function goDetail(item: API.GetFlexTaskListOutput) {
  Taro.navigateTo({
    url: `${RouterPath.jobApplicationDetail}?taskId=${item.taskId}`,
  });
}
</script>

<style lang="scss">
@import '@/styles/common.scss';
</style>
